import yaml
import os
from pydantic import BaseModel, validator
from typing import Optional

class InfererModel(BaseModel):
    project_path: str
    inference_data_path: str
    model_path: str
    device: str
    seq_length: int
    ddconfig_path: Optional[str] = None
    output_probabilities: bool = False
    map_to_id: bool = True

    @validator("inference_data_path")
    def validate_inference_data_path(cls, v, values):
        path = (f"{values['project_path']}/{v}").replace("//", "/")
        if not os.path.exists(path):
            raise ValueError(f"{path} does not exist")
        return(v)


def load_inferer_config(config_path, project_path):
    with open(config_path, "r") as f:
        config_values = yaml.safe_load(f)
    
    config_values["project_path"] = project_path
    return(InfererModel(**config_values))